# RendArr

Render a slice of a .npy array as an image.

Installation:

```sh
pip install rendarr
```

## Usage

```
rendarr <array.npy> [options]
```

This will open a window displaying the array as an image.
If an interactive axis was marked,
you can use the arrow keys to navigate along the interactive axis.

Run `rendarr --help` to see all options.
